@@ -97,7 +97,7 @@ RotatePointAroundVector(vec3_t dst, const vec3_t dir,
 }
 
 void
-AngleVectors(vec3_t angles, vec3_t forward, vec3_t right, vec3_t up)
+AngleVectors(const vec3_t angles, vec3_t forward, vec3_t right, vec3_t up)
 {
 	float angle;
 	static float sr, sp, sy, cr, cp, cy;
@@ -135,9 +135,8 @@ AngleVectors(vec3_t angles, vec3_t forward, vec3_t right, vec3_t up)
 }
 
 void
-AngleVectors2(vec3_t value1, vec3_t angles)
+AngleVectors2(const vec3_t value1, vec3_t angles)
 {
-	float forward;
 	float yaw, pitch;
 
 	if ((value1[1] == 0) && (value1[0] == 0))
@@ -156,6 +155,8 @@ AngleVectors2(vec3_t value1, vec3_t angles)
 	}
 	else
 	{
+		float forward;
+
 		if (value1[0])
 		{
 			yaw = ((float)atan2(value1[1], value1[0]) * 180 / M_PI);
@@ -240,7 +241,7 @@ PerpendicularVector(vec3_t dst, const vec3_t src)
 }
 
 void
-R_ConcatRotations(float in1[3][3], float in2[3][3], float out[3][3])
+R_ConcatRotations(const float in1[3][3], const float in2[3][3], float out[3][3])
 {
 	out[0][0] = in1[0][0] * in2[0][0] + in1[0][1] * in2[1][0] +
 				in1[0][2] * in2[2][0];
@@ -263,7 +264,7 @@ R_ConcatRotations(float in1[3][3], float in2[3][3], float out[3][3])
 }
 
 void
-R_ConcatTransforms(float in1[3][4], float in2[3][4], float out[3][4])
+R_ConcatTransforms(const float in1[3][4], const float in2[3][4], float out[3][4])
 {
 	out[0][0] = in1[0][0] * in2[0][0] + in1[0][1] * in2[1][0] +
 				in1[0][2] * in2[2][0];
@@ -329,7 +330,7 @@ anglemod(float a)
  * This is the slow, general version
  */
 int
-BoxOnPlaneSide2(vec3_t emins, vec3_t emaxs, struct cplane_s *p)
+BoxOnPlaneSide2(const vec3_t emins, const vec3_t emaxs, const struct cplane_s *p)
 {
 	int i;
 	float dist1, dist2;
@@ -371,7 +372,7 @@ BoxOnPlaneSide2(vec3_t emins, vec3_t emaxs, struct cplane_s *p)
  * Returns 1, 2, or 1 + 2
  */
 int
-BoxOnPlaneSide(vec3_t emins, vec3_t emaxs, struct cplane_s *p)
+BoxOnPlaneSide(const vec3_t emins, const vec3_t emaxs, const struct cplane_s *p)
 {
 	float dist1, dist2;
 	int sides;
@@ -471,7 +472,7 @@ ClearBounds(vec3_t mins, vec3_t maxs)
 }
 
 void
-AddPointToBounds(vec3_t v, vec3_t mins, vec3_t maxs)
+AddPointToBounds(const vec3_t v, vec3_t mins, vec3_t maxs)
 {
 	int i;
 	vec_t val;
@@ -492,8 +493,36 @@ AddPointToBounds(vec3_t v, vec3_t mins, vec3_t maxs)
 	}
 }
 
+void
+ClosestPointOnBounds(const vec3_t p, const vec3_t amin, const vec3_t amax, vec3_t out)
+{
+	int i;
+
+	for (i = 0; i < 3; i++)
+	{
+		if (amin[i] > p[i])
+		{
+			out[i] = amin[i];
+		}
+		else if (amax[i] < p[i])
+		{
+			out[i] = amax[i];
+		}
+		else
+		{
+			out[i] = p[i];
+		}
+	}
+}
+
+qboolean
+IsZeroVector(vec3_t v)
+{
+	return (v[0] == 0.0f && v[1] == 0.0f && v[2] == 0.0f);
+}
+
 int
-VectorCompare(vec3_t v1, vec3_t v2)
+VectorCompare(const vec3_t v1, const vec3_t v2)
 {
 	if ((v1[0] != v2[0]) || (v1[1] != v2[1]) || (v1[2] != v2[2]))
 	{
@@ -523,7 +552,7 @@ VectorNormalize(vec3_t v)
 }
 
 vec_t
-VectorNormalize2(vec3_t v, vec3_t out)
+VectorNormalize2(const vec3_t v, vec3_t out)
 {
 	VectorCopy(v, out);
 
@@ -569,17 +598,23 @@ _VectorCopy(vec3_t in, vec3_t out)
 }
 
 void
-CrossProduct(vec3_t v1, vec3_t v2, vec3_t cross)
+CrossProduct(const vec3_t v1, const vec3_t v2, vec3_t cross)
 {
 	cross[0] = v1[1] * v2[2] - v1[2] * v2[1];
 	cross[1] = v1[2] * v2[0] - v1[0] * v2[2];
 	cross[2] = v1[0] * v2[1] - v1[1] * v2[0];
 }
 
+vec_t
+VectorLengthSquared(vec3_t v)
+{
+	return (v[0] * v[0] + v[1] * v[1] + v[2] * v[2]);
+}
+
 double sqrt(double x);
 
 vec_t
-VectorLength(vec3_t v)
+VectorLength(const vec3_t v)
 {
 	return sqrtf((v[0] * v[0]) +
                (v[1] * v[1]) +
@@ -595,13 +630,91 @@ VectorInverse(vec3_t v)
 }
 
 void
-VectorScale(vec3_t in, vec_t scale, vec3_t out)
+VectorInverse2(const vec3_t v, vec3_t out)
+{
+	VectorCopy(v, out);
+	VectorInverse(out);
+}
+
+void
+VectorScale(const vec3_t in, vec_t scale, vec3_t out)
 {
 	out[0] = in[0] * scale;
 	out[1] = in[1] * scale;
 	out[2] = in[2] * scale;
 }
 
+void
+VectorLerp(const vec3_t v1, const vec3_t v2, const vec_t factor, vec3_t out)
+{
+	VectorSubtract(v2, v1, out);
+	VectorScale(out, factor, out);
+	VectorAdd(out, v1, out);
+}
+
+void
+VectorToQuat(const vec3_t v, quat_t out)
+{
+	out[0] = v[0];
+	out[1] = v[1];
+	out[2] = v[2];
+	out[3] = 0.0f;
+}
+
+void
+QuatInverse(const quat_t q, quat_t out)
+{
+	out[0] = -q[0];
+	out[1] = -q[1];
+	out[2] = -q[2];
+	out[3] = q[3];
+}
+
+void
+QuatMultiply(const quat_t q1, const quat_t q2, quat_t out)
+{
+	out[0] = q1[3] * q2[0] + q1[0] * q2[3] + q1[1] * q2[2] - q1[2] * q2[1];
+	out[1] = q1[3] * q2[1] - q1[0] * q2[2] + q1[1] * q2[3] + q1[2] * q2[0];
+	out[2] = q1[3] * q2[2] + q1[0] * q2[1] - q1[1] * q2[0] + q1[2] * q2[3];
+	out[3] = q1[3] * q2[3] - q1[0] * q2[0] - q1[1] * q2[1] - q1[2] * q2[2];
+}
+
+void
+QuatAngleAxis(const vec3_t v, float angle, quat_t out)
+{
+	const vec_t scale = sinf(angle * 0.5f);
+	vec3_t v_out;
+
+	VectorNormalize2(v, v_out);
+	VectorScale(v_out, scale, v_out);
+
+	out[0] = v_out[0];
+	out[1] = v_out[1];
+	out[2] = v_out[2];
+	out[3] = cosf(angle * 0.5f);
+}
+
+void
+RotateVectorByUnitQuat(vec3_t v, quat_t q_unit)
+{
+	quat_t q_vec, q_inv, q_out;
+
+	VectorToQuat(v, q_vec);
+	QuatInverse(q_unit, q_inv);
+	QuatMultiply(q_unit, q_vec, q_out);
+	QuatMultiply(q_out, q_inv, q_out);
+
+	v[0] = q_out[0];
+	v[1] = q_out[1];
+	v[2] = q_out[2];
+}
+
+float
+Q_magnitude(float x, float y)
+{
+	return sqrtf(x * x + y * y);
+}
+
 int
 Q_log2(int val)
 {
