@@ -1699,10 +1699,17 @@ static int RE_PrepareForWindow(void)
 	return SDL_WINDOW_VULKAN;
 }
 
-static void
-RE_SetSky (char *name, float rotate, vec3_t axis)
+static int
+RE_GetSDLVersion(void)
 {
-	RE_SetSky_s (name, rotate, axis);
+#ifdef USE_SDL3
+	int version = SDL_GetVersion();
+	return SDL_VERSIONNUM_MAJOR(version);
+#else
+	SDL_version ver;
+	SDL_VERSION(&ver);
+	return ver.major;
+#endif
 }
 
 /*
@@ -1715,18 +1722,10 @@ GetRefAPI(refimport_t imp)
 {
 	refexport_t refexport = {0};
 
-	// Need to communicate the SDL major version to the client.
-#ifdef USE_SDL3
-	SDL_Version ver;
-#else
-	SDL_version ver;
-#endif
-	SDL_VERSION(&ver);
-
 	ri = imp;
 
 	refexport.api_version = API_VERSION;
-	refexport.framework_version = ver.major;
+	refexport.framework_version = RE_GetSDLVersion();
 
 	refexport.BeginRegistration = RE_BeginRegistration;
 	refexport.RegisterModel = RE_RegisterModel;
